/*
   File: alib.h
   Generated on Thu Mar  4 16:12:21 1993
   Implements the predefines library 'alib'

   CVS ID: "$Id: alib.h,v 1.3 2004/12/25 22:43:36 marcs Exp $"
*/
#ifndef IncAlib
#define IncAlib

extern void pred_makeemptyfield ();
extern void pred_isempty ();
extern void pred_take ();
extern void semipred_showfield ();

extern char *alib_name_from_nodenr ();
extern void init_alib ();

#endif /* IncAlib */
